<?php
/**
 * WK Finance functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WK_Finance
 */

if ( ! function_exists( 'wk_finance_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function wk_finance_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on WK Wow, use a find and replace
	 * to change 'wk-finance' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'wk-finance', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'wk-finance' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	 add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'caption',
	 ) );

	 // Set up the WordPress core custom background feature.
	 add_theme_support( 'custom-background', apply_filters( 'wk_finance_custom_background_args', array(
		'default-color' => 'ffffff',
	 	'default-image' => '',
	 ) ) );

	 // Add theme support for selective refresh for widgets.
	 add_theme_support( 'customize-selective-refresh-widgets' );

     function wk_finance_add_editor_styles() {
        add_editor_style( 'custom-editor-style.css' );
     }
       add_action( 'admin_init', 'wk_finance_add_editor_styles' );

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support(
            'custom-logo',
            array(
                'height'      => 250,
                'width'       => 250,
                'flex-width'  => true,
                'flex-height' => true,
            )
        );
    }
endif;
add_action( 'after_setup_theme', 'wk_finance_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function wk_finance_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'wk_finance_content_width', 1470 );
}
add_action( 'after_setup_theme', 'wk_finance_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function wk_finance_widgets_init() {
    register_sidebar( array(
        'name'          => esc_html__( 'Sidebar', 'wk-finance' ),
        'id'            => 'sidebar-1',
        'description'   => esc_html__( 'Add widgets here.', 'wk-finance' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ) );

    register_sidebar(
        array (
            'name' => esc_html__( 'WooCommerce Sidebar', 'wk-finance' ),
            'id' => 'sidebar-2',
            'description' => esc_html__( 'Add widgets here.', 'wk-finance' ),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget' => '</section>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        )
    );

    register_sidebar( array(
        'name'          => esc_html__( 'Footer 1', 'wk-finance' ),
        'id'            => 'footer-1',
        'description'   => esc_html__( 'Add widgets here.', 'wk-finance' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Footer 2', 'wk-finance' ),
        'id'            => 'footer-2',
        'description'   => esc_html__( 'Add widgets here.', 'wk-finance' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Footer 3', 'wk-finance' ),
        'id'            => 'footer-3',
        'description'   => esc_html__( 'Add widgets here.', 'wk-finance' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ) );
}
add_action( 'widgets_init', 'wk_finance_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function wk_finance_scripts() {
    $headings_font = esc_html(get_theme_mod('headings_fonts'));
    $body_font = esc_html(get_theme_mod('body_fonts'));

    if( $headings_font ) {
        wp_enqueue_style( 'wk_finance-headings-fonts', '//fonts.googleapis.com/css?family='. $headings_font );
    } else {
        wp_enqueue_style( 'wk_finance-source-sans', '//fonts.googleapis.com/css?family=Raleway:400,500,600,700');
    }
    if( $body_font ) {
        wp_enqueue_style( 'wk_finance-body-fonts', '//fonts.googleapis.com/css?family='. $body_font );
    } else {
        wp_enqueue_style( 'wk_finance-source-body', '//https://fonts.googleapis.com/css?family=Raleway:400,500,600,700'); 
    }
	// load bootstrap css
        wp_enqueue_style( 'wk-finance-bootstrap-css', get_template_directory_uri() . '/inc/assets/css/bootstrap.min.css' );
        wp_enqueue_style( 'wk-finance-fontawesome', get_template_directory_uri() . '/inc/assets/css/fontawesome.min.css' );
                       
	// load WK Finance styles
	wp_enqueue_style( 'wk-finance-style', get_stylesheet_uri() );
	wp_enqueue_script('jquery');

    // Internet Explorer HTML5 support
    wp_enqueue_script( 'html5hiv',get_template_directory_uri().'/inc/assets/js/html5.js', array(), '3.7.0', false );
    wp_script_add_data( 'html5hiv', 'conditional', 'lt IE 9' );

	// load bootstrap js
        wp_enqueue_script('wk-finance-popper', get_template_directory_uri() . '/inc/assets/js/popper.min.js', array(), '', true );
        wp_enqueue_script('wk-finance-bootstrapjs', get_template_directory_uri() . '/inc/assets/js/bootstrap.min.js', array(), '', true );
    wp_enqueue_script('wk-finance-themejs', get_template_directory_uri() . '/inc/assets/js/theme-script.min.js', array(), '', true );
	wp_enqueue_script( 'wk-finance-skip-link-focus-fix', get_template_directory_uri() . '/inc/assets/js/skip-link-focus-fix.min.js', array(), '20151215', true );
       wp_enqueue_script( 'wk-finance-custom-js', get_template_directory_uri() . '/inc/assets/js/custom.js' ); 
         wp_enqueue_script( 'wk-finance-jarallax-js', get_template_directory_uri() . '/inc/assets/js/jarallax.js' ); 

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'wk_finance_scripts' );

function wk_finance_password_form() {
    global $post;
    $label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
    $o = '<form action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">
    <div class="d-block mb-3">' . __( "To view this protected post, enter the password below:", "wk-finance" ) . '</div>
    <div class="form-group form-inline"><label for="' . $label . '" class="mr-2">' . __( "Password:", "wk-finance" ) . ' </label><input name="post_password" id="' . $label . '" type="password" size="20" maxlength="20" class="form-control mr-2" /> <input type="submit" name="Submit" value="' . esc_attr__( "Submit", "wk-finance" ) . '" class="btn btn-primary"/></div>
    </form>';
    return $o;
}
add_filter( 'the_password_form', 'wk_finance_password_form' );

/**
 * Custom breadcrumbs
 */
require get_template_directory() . '/inc/breadcrumbs.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Google Fonts
 */
require get_template_directory() . '/inc/gfonts.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load plugin compatibility file.
 */
require get_template_directory() . '/inc/plugin-compatibility/plugin-compatibility.php';

/**
 * Load custom WordPress nav walker.
 */
if ( ! class_exists( 'wp_bootstrap_navwalker' )) {
    require_once(get_template_directory() . '/inc/wp_bootstrap_navwalker.php');
}

// Removing category title() 
add_filter('woocommerce_show_page_title', 'wk_finance_hide_cat_page_title');
 
function wk_finance_hide_cat_page_title($title) {
   if (is_product_category()) $title = false;
   return $title;
}

 // Removing archive title()
add_filter( 'woocommerce_show_page_title', '__return_null' );


 // Remove shop title()
add_filter('woocommerce_show_page_title', 'wk_finance_hide_shop_page_title');
 
function wk_finance_hide_shop_page_title($title) {
   if (is_shop()) $title = false;
   return $title;
}
/**
 * 
 * Place a cart icon with the number of items and total cost in the menu bar.
 */
function wk_finance_wcmenucart($menu, $args) {
    // Check if WooCommerce is active and add a new item to a menu assigned to Primary Navigation Menu location
    if ( !in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) || 'primary' !== $args->theme_location )
        return $menu;
    ob_start();
        global $woocommerce;
        $viewing_cart = __('View your shopping cart', 'wk-finance');
        $start_shopping = __('Start shopping', 'wk-finance');
        $cart_url = wc_get_cart_url();
        $shop_page_url = get_permalink( wc_get_page_id( 'shop' ) );
        $cart_contents_count = $woocommerce->cart->cart_contents_count;
        $cart_contents = sprintf(_n('%d ', '%d ', $cart_contents_count, 'wk-finance'), $cart_contents_count);
        $cart_total = $woocommerce->cart->get_cart_total();
        // Uncomment the line below to hide nav menu cart item when there are no items in the cart
        ///if ( $cart_contents_count > 0 ) {
            if ($cart_contents_count == 0) {
                $menu_item = '<li class="right"><a class="wcmenucart-contents" href="'. $shop_page_url .'" title="'. $start_shopping .'">';
            } else {
                $menu_item = '<li class="right"><a class="wcmenucart-contents" href="'. $cart_url .'" title="'. $viewing_cart .'">';
            }
              // cart icon
            //$menu_item .= '<i class="fas fa-shopping-basket fa-lg "></i> ';
            $menu_item .= $cart_contents.' / '. $cart_total;
            $menu_item .= '</a></li>';
        // Uncomment the line below to hide nav menu cart item when there are no items in the cart
        // }
        echo $menu_item;
    $social = ob_get_clean();
    return $menu . $social;
}

add_filter('wp_nav_menu_items','wk_finance_wcmenucart', 10, 2);
