<?php
/**
 * wk_finance Theme Customizer
 *
 * @package WK_Finance
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wk_finance_sanitize_checkbox( $checked ) {
    // Boolean check.
    return ( ( isset( $checked ) && true == $checked ) ? true : false );
}

/*
 *  Upgrade to pro options
 */ 

function wk_finance_upgrade_pro_options( $wp_customize ) {

    $wp_customize->add_section(
        'upgrade_premium',
        array(
            'title'         => __('Upgrade to Pro','wk-finance'),
            'priority'      => 1,
        )
    );
    
    class wk_finance_WP_Button_Customize_Control extends WP_Customize_Control {
    public $type = 'upgrade_premium';

       function render_content() {
        ?>
            <div class="pro_info">
                <ul>
  
                    <li><a class="upgrade-to-pro" href="https://web-komp.eu/theme/finance" target="_blank"><i class="dashicons dashicons-update-alt"></i><?php _e( 'Upgrade to Pro','wk-finance' ); ?> </a></li>
                </ul>
            </div>
        <?php
       }
    }
    
    $wp_customize->add_setting(
        'pro_info_buttons',
        array(
           'capability'     => 'edit_theme_options',
            'sanitize_callback' => 'wk_finance_sanitize_text',
        )   
    );
    
    $wp_customize->add_control( new wk_finance_WP_Button_Customize_Control( $wp_customize, 'pro_info_buttons', array(
        'section' => 'upgrade_premium',
    ))
);
}
add_action( 'customize_register', 'wk_finance_upgrade_pro_options' );



//select sanitization function
function wk_finance_sanitize_select($input, $setting) {
    $input = sanitize_key($input);
    $choices = $setting->manager->get_control($setting->id)->choices;
    return (array_key_exists($input, $choices) ? $input : $setting->default);
}

function wk_finance_customize_register( $wp_customize ) {

    $wp_customize->add_section(
        'colors',
        array(
            'title' => __( 'Background Color', 'wk-finance' ),
            //'description' => __( 'This is a section for the header banner Image.', 'wk-finance' ),
            'priority' => 50,
            'panel' => 'styling_option_panel',
        )
    );


                // Fonts  
    $wp_customize->add_section(
        'wk_finance_typography',
        array(
            'title' => __('Google Fonts', 'wk-finance' ),   
            'priority' => 45,
    ));
    
    $font_choices = 
        array(
            'Source Sans Pro:400,700,400italic,700italic' => 'Source Sans Pro',
            'Open Sans:400italic,700italic,400,700' => 'Open Sans',
            'Oswald:400,700' => 'Oswald',
            'Playfair Display:400,700,400italic' => 'Playfair Display',
            'Montserrat:400,700' => 'Montserrat',
            'Raleway:400,500,600,700' => 'Raleway',
            'Droid Sans:400,700' => 'Droid Sans',
            'Lato:400,700,400italic,700italic' => 'Lato',
            'Arvo:400,700,400italic,700italic' => 'Arvo',
            'Lora:400,700,400italic,700italic' => 'Lora',
            'Merriweather:400,300italic,300,400italic,700,700italic' => 'Merriweather',
            'Oxygen:400,300,700' => 'Oxygen',
            'PT Serif:400,700' => 'PT Serif', 
            'PT Sans:400,700,400italic,700italic' => 'PT Sans',
            'PT Sans Narrow:400,700' => 'PT Sans Narrow',
            'Cabin:400,700,400italic' => 'Cabin',
            'Fjalla One:400' => 'Fjalla One',
            'Francois One:400' => 'Francois One',
            'Josefin Sans:400,300,600,700' => 'Josefin Sans',  
            'Libre Baskerville:400,400italic,700' => 'Libre Baskerville',
            'Arimo:400,700,400italic,700italic' => 'Arimo',
            'Ubuntu:400,700,400italic,700italic' => 'Ubuntu',
            'Bitter:400,700,400italic' => 'Bitter',
            'Droid Serif:400,700,400italic,700italic' => 'Droid Serif',
            'Roboto:400,400italic,700,700italic' => 'Roboto',
            'Open Sans Condensed:700,300italic,300' => 'Open Sans Condensed',
            'Roboto Condensed:400italic,700italic,400,700' => 'Roboto Condensed',
            'Roboto Slab:400,700' => 'Roboto Slab',
            'Yanone Kaffeesatz:400,700' => 'Yanone Kaffeesatz',
            'Rokkitt:400' => 'Rokkitt',
    );
    
    $wp_customize->add_setting(
        'headings_fonts',
        array(
            'sanitize_callback' => 'wk_finance_sanitize_fonts',
    ));
    
    $wp_customize->add_control(
        'headings_fonts',
        array(
            'type' => 'select',
            'description' => __('Select your desired font for the headings. Raleway is the default Heading font.', 'wk-finance'),
            'section' => 'wk_finance_typography',
            'choices' => $font_choices
    ));
    
    $wp_customize->add_setting(
        'body_fonts',
        array(
            'sanitize_callback' => 'wk_finance_sanitize_fonts',
    ));
    
    $wp_customize->add_control(
        'body_fonts',
        array(
            'type' => 'select',
            'description' => __( 'Select your desired font for the body. Raleway is the default Body font.', 'wk-finance' ), 
            'section' => 'wk_finance_typography',   
            'choices' => $font_choices
    ));


    //Colors
  $wp_customize->add_section(
    'main_color_section',
     array (
    'title' => __( 'Colors', 'wk-finance' ), //Label of your section
    'priority' => 40 //Position in customizer menu
   )
 );

    //Create a setting to database called main_color
  $wp_customize->add_setting(
    'main_color',
     array(
    'default' => '#22B8F0', //default value
    'transport' => 'refresh',//tells customizer to refresh page after change
    'sanitize_callback' => 'sanitize_hex_color'
   ));

    //Create input field and save value to previosly created DB col
 $wp_customize->add_control(
    new WP_Customize_Color_Control(
        $wp_customize,
    'main_color',
     array (
    'label'     =>  __( 'Main color', 'wk-finance' ), 
    'section'   => 'main_color_section', //your section ID
    'settings'  => 'main_color' //your database ID
   ) )
    
    );
  
    $wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
    $wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
    $wp_customize->get_control( 'header_textcolor'  )->section = 'main_color_section';
    $wp_customize->get_control( 'background_color'  )->section = 'main_color_section';

}
add_action( 'customize_register', 'wk_finance_customize_register' );
add_action( 'wp_head', 'wk_finance_customizer_css');
function wk_finance_customizer_css()
{
    ?>
<style type="text/css">
#page-sub-header { background: <?php echo esc_html(get_theme_mod('header_bg_color_setting', '#000')); ?>; }

.topbutton, .dropdown-item:hover, .dropdown-item:focus, .btn-primary, #footer-widget .widget-title:after, .single-contact i.fa, .newsletter-subcribe .form-group .subcribe-submit, .woocommerce nav.woocommerce-pagination ul li a:focus, 
.woocommerce nav.woocommerce-pagination ul li a:hover, 
.woocommerce nav.woocommerce-pagination ul li span.current, .woocommerce span.onsale, .woocommerce div.product form.cart .button, .woocommerce div.product .woocommerce-tabs ul.tabs li.active, #secondary .widget-title:after, .woocommerce #review_form #respond .form-submit input, .woocommerce button.button, .woocommerce-info, .woocommerce #respond input#submit.alt, 
.woocommerce a.button.alt, 
.woocommerce button.button.alt, 
.woocommerce input.button.alt,.single-service:before, .single-service:after, .single-service:hover i.fa, .section-title h4:after, .single-service:hover i.fab, .bg-primary, #wp-calendar #today, .woocommerce .widget_price_filter .ui-slider .ui-slider-handle, .woocommerce .widget_shopping_cart .buttons a, .woocommerce.widget_shopping_cart .buttons a, .woocommerce #respond input#submit:hover, 
.woocommerce button.button:hover, 
.woocommerce input.button:hover, .nav-link:before, .more-link, .spinner > div  {
  background: <?php echo esc_html(get_theme_mod('main_color'));?> !important;
}

 .btn-circle, .widget_tag_cloud .tagcloud a, .single-service:hover i.fa, .single-service:hover i.fab, .widget_product_tag_cloud .tagcloud a   {
   border-color: <?php echo esc_html(get_theme_mod('main_color'));?> !important;
}

.dropdown-menu{
   border-bottom-color: <?php echo esc_html(get_theme_mod('main_color'));?> !important;
}

 a:hover, a:focus, a:active, #secondary ul li a[aria-current=page], #secondary ul a:hover, #secondary ul a:focus,.btn-circle:hover, .btn-circle:focus, .woocommerce-Price-amount, a, .entry-meta .posted-on:before, .entry-meta .author:before, .entry-meta .cat-links:before, .entry-meta .comment-links:before, .fa-comments:before {
  color: <?php echo esc_html(get_theme_mod('main_color'));?>;
}

.text-primary, a.text-primary:focus, a.text-primary:hover, .wk-finance .trail-items .trail-end span   {
  color: <?php echo esc_html(get_theme_mod('main_color'));?>!important;
}
body:not(.theme-preset-active) #masthead .navbar-nav li.active>a  {
  color: <?php echo esc_html(get_theme_mod('main_color'));?>
}

</style>
 <?php
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function wk_finance_customize_preview_js() {
    wp_enqueue_script( 'wk_finance_customizer', get_template_directory_uri() . '/inc/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'wk_finance_customize_preview_js' );
